@@ -10,6 +10,6 @@ pub struct UserDto {
 
 impl UserDto { 
     pub fn from_command_result(result: SubscribeCommandResult) -> Self { 
-        UserDto{public_key: String::from("somePublicKey")}
+        UserDto{public_key: result.user().public_key().value().clone()}
     }
 }
